{% extends "bee_django_course/base.html" %}
{% load bee_django_course_filter %}
{% block content %}
    <h4>录制视频详情</h4>
    <div class="video">
        <iframe src="{{ record_video_id | get_video_src }}" frameborder="0" width="100%" height="100%"></iframe>
    </div>
{% endblock %}
{% block scripts %}
    <script>
        function get_custom_id() {
            // 用户获取待设置的自定义参数的逻辑 var custom_id="aaaaaaaaa";
            return '{{ request.user.id }}';
        }
    </script>
{% endblock %}